@@ -1,5 +1,5 @@
-# $Id: Document.pm 35761 2011-10-12 18:45:02Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Attributes/Document.pm $
+# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Attributes/Document.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -7,23 +7,22 @@ use utf8;
 
 package Aselect::UI::Attributes::Document;
 
-use Xyzzy::Util qw(iso8601);
-
 use Aselect::UI::Document -self;
 
+use constant rootname => 'attributes';
+
 sub build {
 	my $req = $self->req;
 	my $cfg = $self->cfg;
 
-	my $root = $self->construct('attributes');
-	$self->setDocumentElement($root);
+	my $root = $self->documentElement;
 
-	if(my $uid = $req->uid) {
+	if(my $uid = $req->new_session->uid) {
 		my $requestors = $cfg->requestors;
 
 		if(my $app_id = $req->app_id) {
 			my $requestor = $requestors->{$app_id}
-				or die $req->error('app_id', undef, app_id => $app_id);
+				or die $req->errorpage('app_id', undef, app_id => $app_id);
 			$root->appendTextChild('app_id', $app_id);
 
 			my $attributes = $cfg->dir->attributes($uid, $requestor);
