@@ -1,5 +1,5 @@
-# $Id: Document.pm 36052 2011-11-17 18:43:03Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Login/Document.pm $
+# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Login/Document.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -10,8 +10,6 @@ package Aselect::UI::Login::Document;
 use Aselect::UI::Document -self;
 
 sub build {
-	$self->hook_next;
-
 	my $req = $self->req;
 
 	my $login = $self->construct('login' =>
@@ -19,6 +17,10 @@ sub build {
 		[remember => $req->effective_remember],
 	);
 
+	if(my $uid = $req->uid) {
+		$login->appendChild($self->construct(uid => $uid));
+	}
+
 	if(my $rid = $req->rid) {
 		$login->appendChild($self->construct(rid => $rid));
 	}
