@@ -1,5 +1,5 @@
-# $Id: Document.pm 35498 2011-09-02 14:34:30Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Static/Document.pm $
+# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Static/Document.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -11,3 +11,5 @@ use Xyzzy::Static;
 
 use Aselect::UI::Document -self;
 use Xyzzy::Static::Document -mixin;
+
+use constant rootname => 'document';
